
Developer docs
==============
To learn about the inner workings of the ``ricecooker`` library, consult the following pages:

.. toctree::
   :maxdepth: 1

   ../chefops
   sushops
   kolibripreview
   ids
   uploadprocess
   design_cli
   daemonization
   corrections


